Struct MmioTransport
pub struct MmioTransport<'a> { /* private fields */ }Expand description
MMIO Device Register Interface.
Ref: 4.2.2 MMIO Device Register Layout and 4.2.4 Legacy interface
Implementations
impl<'a> MmioTransport<'a>
impl<'a> MmioTransport<'a>
pub unsafe fn new(
header: NonNull<VirtIOHeader>,
mmio_size: usize,
) -> Result<MmioTransport<'a>, MmioError>
pub unsafe fn new( header: NonNull<VirtIOHeader>, mmio_size: usize, ) -> Result<MmioTransport<'a>, MmioError>
Constructs a new VirtIO MMIO transport, or returns an error if the header reports an unsupported version.
Safety
header must point to a properly aligned valid VirtIO MMIO region, which must remain valid
for the lifetime 'a. This includes the config space following the header, if any.
pub fn new_from_unique(
header: UniqueMmioPointer<'a, VirtIOHeader>,
config_space: UniqueMmioPointer<'a, [u8]>,
) -> Result<MmioTransport<'a>, MmioError>
pub fn new_from_unique( header: UniqueMmioPointer<'a, VirtIOHeader>, config_space: UniqueMmioPointer<'a, [u8]>, ) -> Result<MmioTransport<'a>, MmioError>
Constructs a new VirtIO MMIO transport, or returns an error if the header reports an unsupported version.
pub fn version(&self) -> MmioVersion
pub fn version(&self) -> MmioVersion
Gets the version of the VirtIO MMIO transport.